# frozen_string_literal: true

require 'test_plugin_helper'

if defined? RedhatAccess
  module ForemanAnsible
    # Tests for the RH Insights plan runner. Mostly about checking whether
    # the playbook can be parsed properly
    class InsightsPlanRunnerTest < ActiveSupport::TestCase
      test 'disclaimer is saved as raw_playbook' do
        disclaimer = <<-DISCLAIMER.strip_heredoc.strip
  # Red Hat Insights has recommended one or more actions for you, a system administrator, to review and if you
  # deem appropriate, deploy on your systems running Red Hat software. Based on the analysis, we have automatically
  # generated an Ansible Playbook for you. Please review and test the recommended actions and the Playbook as
  # they may contain configuration changes, updates, reboots and/or other changes to your systems. Red Hat is not
  # responsible for any adverse outcomes related to these recommendations or Playbooks.
  #
  # Addresses maintenance plan 38439429 (demo)
  # https://access.redhat.com/insights/planner/438294928
  # Generated by Red Hat Insights on Wed, 18 Apr 2018 07:54:18 GMT
        DISCLAIMER

        playbook = File.read(ansible_fixture_file('insights_playbook.yaml'))
        planner = ::ForemanAnsible::InsightsPlanRunner.new(
          FactoryBot.build(:organization), rand
        )
        assert_empty planner.parse_disclaimer
        planner.expects(:insights_api_host).returns('')
        planner.expects(:get_ssl_options_for_org).returns(nil)
        RestClient::Resource.any_instance.expects(:get).returns(
          OpenStruct.new(:body => playbook)
        )
        planner.playbook
        assert_equal disclaimer, planner.parse_disclaimer
      end
    end
  end
end
